@@ -42,7 +42,7 @@ def clear_pypi_info_cache():
 
 def test_manual_upgrade(session_app_data, caplog, mocker, for_py_version):
     wheel = get_embed_wheel("pip", for_py_version)
-    new_version = NewVersion(wheel.path, datetime.now(), datetime.now() - timedelta(days=20))
+    new_version = NewVersion(wheel.path, datetime.now(), datetime.now() - timedelta(days=20), "manual")
 
     def _do_update(distribution, for_py_version, embed_filename, app_data, search_dirs, periodic):  # noqa
         if distribution == "pip":
@@ -73,7 +73,7 @@ def test_pick_periodic_update(tmp_path, session_app_data, mocker, for_py_version
     u_log = UpdateLog(
         started=datetime.now() - timedelta(days=30),
         completed=completed,
-        versions=[NewVersion(filename=current.path, found_date=completed, release_date=completed)],
+        versions=[NewVersion(filename=current.path, found_date=completed, release_date=completed, source="periodic")],
         periodic=True,
     )
     read_dict = mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.read", return_value=u_log.to_dict())
@@ -93,40 +93,86 @@ def test_periodic_update_stops_at_current(mocker, session_app_data, for_py_versi
         started=completed,
         completed=completed,
         versions=[
-            NewVersion(wheel_path(current, (1,)), completed, now - timedelta(days=1)),
-            NewVersion(filename=current.path, found_date=completed, release_date=now - timedelta(days=2)),
-            NewVersion(wheel_path(current, (-1,)), completed, now - timedelta(days=30)),
+            NewVersion(wheel_path(current, (1,)), completed, now - timedelta(days=1), "periodic"),
+            NewVersion(current.path, completed, now - timedelta(days=2), "periodic"),
+            NewVersion(wheel_path(current, (-1,)), completed, now - timedelta(days=30), "periodic"),
         ],
         periodic=True,
     )
     mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.read", return_value=u_log.to_dict())
 
-    result = periodic_update("setuptools", for_py_version, current, [], session_app_data, False, os.environ)
+    result = periodic_update("setuptools", None, for_py_version, current, [], session_app_data, False, os.environ)
     assert result.path == current.path
 
 
 def test_periodic_update_latest_per_patch(mocker, session_app_data, for_py_version):
     current = get_embed_wheel("setuptools", for_py_version)
-    now, completed = datetime.now(), datetime.now() - timedelta(days=29)
+    expected_path = wheel_path(current, (0, 1, 2))
+    now = datetime.now()
+    completed = now - timedelta(hours=2)
     u_log = UpdateLog(
         started=completed,
         completed=completed,
-        versions=[
-            NewVersion(wheel_path(current, (0, 1, 2)), completed, now - timedelta(days=1)),
-            NewVersion(wheel_path(current, (0, 1, 1)), completed, now - timedelta(days=30)),
-            NewVersion(filename=str(current.path), found_date=completed, release_date=now - timedelta(days=2)),
-        ],
         periodic=True,
+        versions=[
+            NewVersion(expected_path, completed, now - timedelta(days=1), "periodic"),
+            NewVersion(wheel_path(current, (0, 1, 1)), completed, now - timedelta(days=30), "periodic"),
+            NewVersion(str(current.path), completed, now - timedelta(days=31), "periodic"),
+        ],
     )
     mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.read", return_value=u_log.to_dict())
 
-    result = periodic_update("setuptools", for_py_version, current, [], session_app_data, False, os.environ)
-    assert result.path == current.path
+    result = periodic_update("setuptools", None, for_py_version, current, [], session_app_data, False, os.environ)
+    assert str(result.path) == expected_path
 
 
-def wheel_path(wheel, of):
+def test_periodic_update_latest_per_patch_prev_is_manual(mocker, session_app_data, for_py_version):
+    current = get_embed_wheel("setuptools", for_py_version)
+    expected_path = wheel_path(current, (0, 1, 2))
+    now = datetime.now()
+    completed = now - timedelta(hours=2)
+    u_log = UpdateLog(
+        started=completed,
+        completed=completed,
+        periodic=True,
+        versions=[
+            NewVersion(expected_path, completed, completed, "periodic"),
+            NewVersion(wheel_path(current, (0, 1, 1)), completed, now - timedelta(days=10), "manual"),
+            NewVersion(wheel_path(current, (0, 1, 0)), completed, now - timedelta(days=11), "periodic"),
+            NewVersion(str(current.path), completed, now - timedelta(days=12), "manual"),
+        ],
+    )
+    mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.read", return_value=u_log.to_dict())
+
+    result = periodic_update("setuptools", None, for_py_version, current, [], session_app_data, False, os.environ)
+    assert str(result.path) == expected_path
+
+
+def test_manual_update_honored(mocker, session_app_data, for_py_version):
+    current = get_embed_wheel("setuptools", for_py_version)
+    expected_path = wheel_path(current, (0, 1, 1))
+    now = datetime.now()
+    completed = now
+    u_log = UpdateLog(
+        started=completed,
+        completed=completed,
+        periodic=True,
+        versions=[
+            NewVersion(wheel_path(current, (0, 1, 2)), completed, completed, "periodic"),
+            NewVersion(expected_path, completed, now - timedelta(days=10), "manual"),
+            NewVersion(wheel_path(current, (0, 1, 0)), completed, now - timedelta(days=11), "periodic"),
+            NewVersion(str(current.path), completed, now - timedelta(days=12), "manual"),
+        ],
+    )
+    mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.read", return_value=u_log.to_dict())
+
+    result = periodic_update("setuptools", None, for_py_version, current, [], session_app_data, False, os.environ)
+    assert str(result.path) == expected_path
+
+
+def wheel_path(wheel, of, pre_release=""):
     new_version = ".".join(str(i) for i in (tuple(sum(x) for x in zip_longest(wheel.version_tuple, of, fillvalue=0))))
-    new_name = wheel.name.replace(wheel.version, new_version)
+    new_name = wheel.name.replace(wheel.version, new_version + pre_release)
     return str(wheel.path.parent / new_name)
 
 
@@ -166,7 +212,7 @@ def test_periodic_update_skip(u_log, mocker, for_py_version, session_app_data, f
     mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.read", return_value=u_log.to_dict())
     mocker.patch("virtualenv.seed.wheels.periodic_update.trigger_update", side_effect=RuntimeError)
 
-    result = periodic_update("setuptools", for_py_version, None, [], session_app_data, os.environ, True)
+    result = periodic_update("setuptools", None, for_py_version, None, [], session_app_data, os.environ, True)
     assert result is None
 
 
@@ -194,7 +240,7 @@ def test_periodic_update_trigger(u_log, mocker, for_py_version, session_app_data
     write = mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.write")
     trigger_update_ = mocker.patch("virtualenv.seed.wheels.periodic_update.trigger_update")
 
-    result = periodic_update("setuptools", for_py_version, None, [], session_app_data, os.environ, True)
+    result = periodic_update("setuptools", None, for_py_version, None, [], session_app_data, os.environ, True)
 
     assert result is None
     assert trigger_update_.call_count
@@ -338,7 +384,7 @@ def test_do_update_first(tmp_path, mocker, freezer):
     assert copy.call_count == 1
 
     expected = [
-        NewVersion(Path(wheel).name, _UP_NOW, None if release is None else release.replace(microsecond=0))
+        NewVersion(Path(wheel).name, _UP_NOW, None if release is None else release.replace(microsecond=0), "periodic")
         for wheel, release in pip_version_remote
     ]
     assert versions == expected
@@ -371,7 +417,7 @@ def test_do_update_skip_already_done(tmp_path, mocker, freezer):
     u_log = UpdateLog(
         started=_UP_NOW - timedelta(days=31),
         completed=released,
-        versions=[NewVersion(filename=wheel.path.name, found_date=released, release_date=released)],
+        versions=[NewVersion(filename=wheel.path.name, found_date=released, release_date=released, source="periodic")],
         periodic=True,
     )
     read_dict = mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.read", return_value=u_log.to_dict())
@@ -395,21 +441,20 @@ def test_do_update_skip_already_done(tmp_path, mocker, freezer):
                 "filename": wheel.path.name,
                 "release_date": dump_datetime(released),
                 "found_date": dump_datetime(released),
+                "source": "manual",  # changed from "periodic" to "manual"
             },
         ],
     }
 
 
 def test_new_version_eq():
-    value = NewVersion("a", datetime.now(), datetime.now())
+    value = NewVersion("a", datetime.now(), datetime.now(), "periodic")
     assert value == value
 
 
 def test_new_version_ne():
-    assert NewVersion("a", datetime.now(), datetime.now()) != NewVersion(
-        "a",
-        datetime.now(),
-        datetime.now() + timedelta(hours=1),
+    assert NewVersion("a", datetime.now(), datetime.now(), "periodic") != NewVersion(
+        "a", datetime.now(), datetime.now() + timedelta(hours=1), "manual"
     )
 
 
@@ -443,21 +488,25 @@ def test_get_release_fails(mocker, caplog):
     assert repr(exc) in caplog.text
 
 
+def mock_download(mocker, pip_version_remote):
+    def download():
+        index = 0
+        while True:
+            path = pip_version_remote[index]
+            index += 1
+            yield Wheel(Path(path))
+
+    do = download()
+    return mocker.patch("virtualenv.seed.wheels.acquire.download_wheel", side_effect=lambda *a, **k: next(do))
+
+
 def test_download_stop_with_embed(tmp_path, mocker, freezer):
     freezer.move_to(_UP_NOW)
     wheel = get_embed_wheel("pip", "3.9")
     app_data_outer = AppDataDiskFolder(str(tmp_path / "app"))
     pip_version_remote = [wheel_path(wheel, (0, 0, 2)), wheel_path(wheel, (0, 0, 1)), wheel_path(wheel, (-1, 0, 0))]
-    at = {"index": 0}
 
-    def download():
-        while True:
-            path = pip_version_remote[at["index"]]
-            at["index"] += 1
-            yield Wheel(Path(path))
-
-    do = download()
-    download_wheel = mocker.patch("virtualenv.seed.wheels.acquire.download_wheel", side_effect=lambda *a, **k: next(do))
+    download_wheel = mock_download(mocker, pip_version_remote)
     url_o = mocker.patch("virtualenv.seed.wheels.periodic_update.urlopen", side_effect=URLError("unavailable"))
 
     last_update = _UP_NOW - timedelta(days=14)
@@ -472,3 +521,139 @@ def test_download_stop_with_embed(tmp_path, mocker, freezer):
 
     assert read_dict.call_count == 1
     assert write.call_count == 1
+
+
+def test_download_manual_stop_after_one_download(tmp_path, mocker, freezer):
+    freezer.move_to(_UP_NOW)
+    wheel = get_embed_wheel("pip", "3.9")
+    app_data_outer = AppDataDiskFolder(str(tmp_path / "app"))
+    pip_version_remote = [wheel_path(wheel, (0, 1, 1))]
+
+    download_wheel = mock_download(mocker, pip_version_remote)
+    url_o = mocker.patch("virtualenv.seed.wheels.periodic_update.urlopen", side_effect=URLError("unavailable"))
+
+    last_update = _UP_NOW - timedelta(days=14)
+    u_log = UpdateLog(started=last_update, completed=last_update, versions=[], periodic=True)
+    read_dict = mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.read", return_value=u_log.to_dict())
+    write = mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.write")
+
+    do_update("pip", "3.9", str(wheel.path), str(app_data_outer), [], False)
+
+    assert download_wheel.call_count == 1
+    assert url_o.call_count == 2
+    assert read_dict.call_count == 1
+    assert write.call_count == 1
+
+
+def test_download_manual_ignores_pre_release(tmp_path, mocker, freezer):
+    freezer.move_to(_UP_NOW)
+    wheel = get_embed_wheel("pip", "3.9")
+    app_data_outer = AppDataDiskFolder(str(tmp_path / "app"))
+    pip_version_remote = [wheel_path(wheel, (0, 0, 1))]
+    pip_version_pre = NewVersion(Path(wheel_path(wheel, (0, 1, 0), "b1")).name, _UP_NOW, None, "downloaded")
+
+    download_wheel = mock_download(mocker, pip_version_remote)
+    url_o = mocker.patch("virtualenv.seed.wheels.periodic_update.urlopen", side_effect=URLError("unavailable"))
+
+    last_update = _UP_NOW - timedelta(days=14)
+    u_log = UpdateLog(started=last_update, completed=last_update, versions=[pip_version_pre], periodic=True)
+    read_dict = mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.read", return_value=u_log.to_dict())
+    write = mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.write")
+
+    do_update("pip", "3.9", str(wheel.path), str(app_data_outer), [], False)
+
+    assert download_wheel.call_count == 1
+    assert url_o.call_count == 2
+    assert read_dict.call_count == 1
+    assert write.call_count == 1
+    wrote_json = write.call_args[0][0]
+    assert wrote_json["versions"] == [
+        {
+            "filename": Path(pip_version_remote[0]).name,
+            "release_date": None,
+            "found_date": dump_datetime(_UP_NOW),
+            "source": "manual",
+        },
+        pip_version_pre.to_dict(),
+    ]
+
+
+def test_download_periodic_stop_at_first_usable(tmp_path, mocker, freezer):
+    freezer.move_to(_UP_NOW)
+    wheel = get_embed_wheel("pip", "3.9")
+    app_data_outer = AppDataDiskFolder(str(tmp_path / "app"))
+    pip_version_remote = [wheel_path(wheel, (0, 1, 1)), wheel_path(wheel, (0, 1, 0))]
+    rel_date_remote = [_UP_NOW - timedelta(days=1), _UP_NOW - timedelta(days=30)]
+
+    download_wheel = mock_download(mocker, pip_version_remote)
+
+    rel_date_gen = iter(rel_date_remote)
+    release_date = mocker.patch(
+        "virtualenv.seed.wheels.periodic_update.release_date_for_wheel_path",
+        side_effect=lambda *a, **k: next(rel_date_gen),
+    )
+
+    last_update = _UP_NOW - timedelta(days=14)
+    u_log = UpdateLog(started=last_update, completed=last_update, versions=[], periodic=True)
+    read_dict = mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.read", return_value=u_log.to_dict())
+    write = mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.write")
+
+    do_update("pip", "3.9", str(wheel.path), str(app_data_outer), [], True)
+
+    assert download_wheel.call_count == 2
+    assert release_date.call_count == 2
+    assert read_dict.call_count == 1
+    assert write.call_count == 1
+
+
+def test_download_periodic_stop_at_first_usable_with_previous_minor(tmp_path, mocker, freezer):
+    freezer.move_to(_UP_NOW)
+    wheel = get_embed_wheel("pip", "3.9")
+    app_data_outer = AppDataDiskFolder(str(tmp_path / "app"))
+    pip_version_remote = [wheel_path(wheel, (0, 1, 1)), wheel_path(wheel, (0, 1, 0)), wheel_path(wheel, (0, -1, 0))]
+    rel_date_remote = [_UP_NOW - timedelta(days=1), _UP_NOW - timedelta(days=30), _UP_NOW - timedelta(days=40)]
+    downloaded_versions = [
+        NewVersion(Path(pip_version_remote[2]).name, rel_date_remote[2], None, "download"),
+        NewVersion(Path(pip_version_remote[0]).name, rel_date_remote[0], None, "download"),
+    ]
+
+    download_wheel = mock_download(mocker, pip_version_remote)
+
+    rel_date_gen = iter(rel_date_remote)
+    release_date = mocker.patch(
+        "virtualenv.seed.wheels.periodic_update.release_date_for_wheel_path",
+        side_effect=lambda *a, **k: next(rel_date_gen),
+    )
+
+    last_update = _UP_NOW - timedelta(days=14)
+    u_log = UpdateLog(
+        started=last_update,
+        completed=last_update,
+        versions=downloaded_versions,
+        periodic=True,
+    )
+    read_dict = mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.read", return_value=u_log.to_dict())
+    write = mocker.patch("virtualenv.app_data.via_disk_folder.JSONStoreDisk.write")
+
+    do_update("pip", "3.9", str(wheel.path), str(app_data_outer), [], True)
+
+    assert download_wheel.call_count == 2
+    assert release_date.call_count == 2
+    assert read_dict.call_count == 1
+    assert write.call_count == 1
+    wrote_json = write.call_args[0][0]
+    assert wrote_json["versions"] == [
+        {
+            "filename": Path(pip_version_remote[0]).name,
+            "release_date": dump_datetime(rel_date_remote[0]),
+            "found_date": dump_datetime(_UP_NOW),
+            "source": "periodic",
+        },
+        {
+            "filename": Path(pip_version_remote[1]).name,
+            "release_date": dump_datetime(rel_date_remote[1]),
+            "found_date": dump_datetime(_UP_NOW),
+            "source": "periodic",
+        },
+        downloaded_versions[0].to_dict(),
+    ]
